@@ -1,31 +1,73 @@
-package HTML::FormFu::Constraint;
-
 use strict;
-use base 'HTML::FormFu::Processor';
-use MRO::Compat;
-use mro 'c3';
+
+package HTML::FormFu::Constraint;
+$HTML::FormFu::Constraint::VERSION = '2.07';
+# ABSTRACT: Constrain User Input
+
+use Moose;
+use MooseX::Attribute::Chained;
+extends 'HTML::FormFu::Processor';
 
 use HTML::FormFu::Exception::Constraint;
 use HTML::FormFu::Util qw(
     DEBUG_CONSTRAINTS
+    DEBUG_CONSTRAINTS_WHEN
     debug
 );
-use Carp qw( croak );
 use Clone ();
-use List::MoreUtils qw( any );
-use List::Util qw( first );
+use Carp qw( croak );
+use List::Util 1.33 qw( any all first );
 use Scalar::Util qw( reftype blessed );
 
-__PACKAGE__->mk_accessors(qw( only_on_reps ));
+has not          => ( is => 'rw', traits => ['Chained'] );
+has force_errors => ( is => 'rw', traits => ['Chained'] );
+has when         => ( is => 'rw', traits => ['Chained'] );
+has only_on_reps => ( is => 'rw', traits => ['Chained'] );
 
-__PACKAGE__->mk_item_accessors(qw( not force_errors when ));
+sub repeatable_repeat {
+    my ( $self, $repeatable, $new_block ) = @_;
+
+    my $block_fields = $new_block->get_fields;
+
+    # rename any 'when' fields
+    {
+        my $when = $self->when;
+
+        if ( my $name = $when->{field} ) {
+            my $field = $repeatable->get_field_with_original_name( $name,
+                $block_fields );
+
+            if ( defined $field ) {
+                DEBUG_CONSTRAINTS && debug(
+                    sprintf
+                        "Repeatable renaming constraint 'when{field}' '%s' to '%s'",
+                    $name, $field->nested_name,
+                );
+
+                $when->{field} = $field->nested_name;
+            }
+        }
+        elsif ( my $names = $when->{fields} ) {
+            for my $name (@$names) {
+                my $field = $repeatable->get_field_with_original_name( $name,
+                    $block_fields );
+
+                if ( defined $field ) {
+                    $when->{field} = $field->nested_name;
+                }
+            }
+        }
+    }
+}
+
+sub pre_process { }
 
 sub process {
     my ( $self, $params ) = @_;
 
     return unless $self->_run_this_rep;
 
-    my $value = $self->_find_field_value( $params );
+    my $value = $self->_find_field_value($params);
 
     my @errors;
 
@@ -40,8 +82,8 @@ sub process {
 
         if ($@) {
             push @errors,
-                $self->mk_errors( {
-                    pass    => 0,
+                $self->mk_errors(
+                {   pass    => 0,
                     message => $@,
                 } );
         }
@@ -53,8 +95,8 @@ sub process {
         DEBUG_CONSTRAINTS && debug( '$@' => $@ );
 
         push @errors,
-            $self->mk_errors( {
-                pass => ( $@ || !$ok ) ? 0 : 1,
+            $self->mk_errors(
+            {   pass => ( $@ || !$ok ) ? 0 : 1,
                 message => $@,
             } );
     }
@@ -64,16 +106,16 @@ sub process {
 
 sub _run_this_rep {
     my ($self) = @_;
-    
+
     my $only_on_reps = $self->only_on_reps
         or return 1;
-    
+
     my $current_rep = $self->field->repeatable_count
         or return 1;
-    
+
     $only_on_reps = [$only_on_reps]
         if ( reftype($only_on_reps) || '' ) ne 'ARRAY';
-    
+
     return first { $current_rep == $_ } @$only_on_reps;
 }
 
@@ -82,37 +124,38 @@ sub _find_field_value {
 
     my $value = $self->get_nested_hash_value( $params, $self->nested_name );
 
-    my @fields_with_this_name = @{ $self->form->get_fields({ nested_name => $self->nested_name }) };
-    
+    my @fields_with_this_name
+        = @{ $self->form->get_fields( { nested_name => $self->nested_name } ) };
+
     if ( @fields_with_this_name > 1 ) {
         my $field = $self->parent;
         my $index;
-        
-        for ( my $i=0; $i <= $#fields_with_this_name; ++$i ) {
+
+        for ( my $i = 0; $i <= $#fields_with_this_name; ++$i ) {
             if ( $fields_with_this_name[$i] eq $field ) {
                 $index = $i;
                 last;
             }
         }
-        
+
         croak 'did not find ourself - how can this happen?'
             if !defined $index;
-        
-        if ( reftype($value) eq 'ARRAY' ) {
+
+        if ( ( reftype($value) || '' ) eq 'ARRAY' ) {
             $value = $value->[$index];
         }
         elsif ( $index == 0 ) {
+
             # keep $value
         }
         else {
             undef $value;
         }
     }
-    
+
     return $value;
 }
 
-
 sub constrain_values {
     my ( $self, $values, $params ) = @_;
 
@@ -125,8 +168,8 @@ sub constrain_values {
         DEBUG_CONSTRAINTS && debug( '$@' => $@ );
 
         push @errors,
-            $self->mk_errors( {
-                pass => ( $@ || !$ok ) ? 0 : 1,
+            $self->mk_errors(
+            {   pass => ( $@ || !$ok ) ? 0 : 1,
                 message => $@,
             } );
     }
@@ -171,9 +214,9 @@ sub mk_error {
 sub _process_when {
     my ( $self, $params ) = @_;
 
-    # returns 1 if when condition is fullfilled or not defined
-    # returns 0 if when condition is defined and not fullfilled
-    # If it's a callback, return callback's return value (so when
+    # returns 1 if when condition is fulfilled or not defined
+    # returns 0 if when condition is defined and not fulfilled
+    # If it's a callback, return callback's return value (so 'when'
     # condition is met if callback returns a true value)
 
     # get when condition
@@ -184,20 +227,61 @@ sub _process_when {
     croak "Parameter 'when' is not a hash ref" if ref $when ne 'HASH';
 
     # field or callback must be defined
-    my $when_field    = $when->{field};
-    my $when_callback = $when->{callback};
-    croak "Parameter 'field' or 'callback' is not defined"
-        if !defined $when_field && !defined $when_callback;
+    my $when_field     = $when->{field};
+    my $when_fields    = $when->{fields};
+    my $when_any_field = $when->{any_field};
+    my $when_callback  = $when->{callback};
+
+    croak
+        "'field', 'fields', 'any_field' or 'callback' key must be defined in 'when'"
+        if all { !defined } $when_field, $when_fields, $when_any_field,
+        $when_callback;
 
     # Callback will be the preferred thing
     if ($when_callback) {
+        ## no critic (ProhibitNoStrict);
         no strict 'refs';
-        return $when_callback->($params);
+        return $when_callback->( $params, $self );
     }
 
-    # nothing to constrain if field doesn't exist
-    my $when_field_value = $self->get_nested_hash_value( $params, $when_field );
-    return 0 if !defined $when_field_value;
+    my $any;
+    my @when_fields_value;
+
+    if ($when_any_field) {
+        croak "'any_field' is set to an empty list" if !@$when_any_field;
+
+        $any = 1;
+
+        @$when_fields = @$when_any_field;
+    }
+
+    if ($when_fields) {
+        croak "'fields' is set to an empty list" if !@$when_fields;
+
+        for my $name (@$when_fields) {
+            my $value = $self->get_nested_hash_value( $params, $name );
+
+            push @when_fields_value, $value
+                if defined $value;
+        }
+    }
+    else {
+
+        # nothing to constrain if field doesn't exist
+        my $value = $self->get_nested_hash_value( $params, $when_field );
+
+        push @when_fields_value, $value
+            if defined $value;
+    }
+
+    DEBUG_CONSTRAINTS_WHEN
+        && debug( 'WHEN_FIELDS_VALUES' => \@when_fields_value );
+
+    if ( !@when_fields_value ) {
+        DEBUG_CONSTRAINTS_WHEN
+            && debug("No 'when' fields values exist - returning false");
+        return 0;
+    }
 
     my @values;
 
@@ -209,25 +293,47 @@ sub _process_when {
     }
 
     # determine if condition is fulfilled
-    my $ok;
+    my @ok;
 
     if (@values) {
-        $ok = any { $when_field_value eq $_ } @values;
+        for my $value (@when_fields_value) {
+            push @ok, any { $value eq $_ } @values;
+        }
     }
     else {
-        $ok = $when_field_value ? 1 : 0;
+        for my $value (@when_fields_value) {
+            push @ok, $value ? 1 : 0;
+        }
     }
 
-    # invert when condition if asked for
-    $ok = $when->{not} ? !$ok : $ok;
+    DEBUG_CONSTRAINTS_WHEN && debug( "'when' value matches" => \@ok );
 
-    return $ok;
+    my $return
+        = $any
+        ? any { $when->{not} ? !$_ : $_ } @ok
+        : all { $when->{not} ? !$_ : $_ } @ok;
+
+    DEBUG_CONSTRAINTS_WHEN && debug( "'when' return value" => $return );
+
+    return $return;
+}
+
+sub fetch_error_message {
+    my ($self) = @_;
+
+    my $error = HTML::FormFu::Exception::Constraint->new(
+        {   form      => $self->form,
+            parent    => $self->parent,
+            processor => $self,
+        } );
+
+    return $error->message;
 }
 
 sub clone {
     my $self = shift;
 
-    my $clone = $self->next::method(@_);
+    my $clone = $self->SUPER::clone(@_);
 
     if ( defined( my $when = $self->when ) ) {
         $clone->when( Clone::clone $when );
@@ -236,14 +342,24 @@ sub clone {
     return $clone;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Constraint - Constrain User Input
 
+=head1 VERSION
+
+version 2.07
+
 =head1 SYNOPSIS
 
     ---
@@ -286,7 +402,7 @@ See L<HTML::FormFu/"FORM LOGIC AND VALIDATION"> for further details.
 
 L<HTML::FormFu/constraints> can be called on any L<form|HTML::FormFu>,
 L<block element|HTML::FormFu::Element::Block> (includes fieldsets) or
-L<field element|HTML::FormFu::Element::_Field>.
+L<field element|HTML::FormFu::Role::Element::Field>.
 
 If called on a field element, no C<name> argument should be passed.
 
@@ -318,7 +434,7 @@ Argument: \@repeatable_count
 For constraints added to fields within a
 L<Repeatable|HTML::FormFu::Element::Repeatable> element, if C<only_on_reps>
 is set, the constraint will only be run for fields whose
-L<repeatable_count|HTML::FormFu::Element::_Field/repeatable_count>
+L<repeatable_count|HTML::FormFu::Role::Element::Field/repeatable_count>
 matches one of these set values.
 
 Not available for the constraints listed in
@@ -354,7 +470,7 @@ See L<HTML::FormFu/force_errors> for details.
 
 =head2 parent
 
-Returns the L<field|HTML::FormFu::Element::_Field> object that the constraint
+Returns the L<field|HTML::FormFu::Role::Element::Field> object that the constraint
 is associated with.
 
 =head2 form
@@ -368,7 +484,7 @@ Shorthand for C<< $constraint->parent->name >>
 
 =head2 when
 
-Defines a condition for the constraint. Only when the condition is fullfilled
+Defines a condition for the constraint. Only when the condition is fulfilled
 the constraint will be applied.
 
 This method expects a hashref.
@@ -384,7 +500,19 @@ The following keys are supported:
 
 =item field
 
-nested-name of form field that shall be checked against
+Nested-name of form field that shall be checked against - if C<< when->{value} >>
+is set, the C<when> condition passes if the named field's value matches that,
+otherwise the C<when> condition passes if the named field's value is true.
+
+=item fields
+
+Array-ref of nested-names that shall be checked. The C<when> condition passes
+if all named-fields' values pass, using the same rules as C<field> above.
+
+=item any_field
+
+Array-ref of nested-names that shall be checked. The C<when> condition passes
+if any named-fields' values pass, using the same rules as C<field> above.
 
 =item value
 
@@ -392,7 +520,7 @@ Expected value in the form field 'field'
 
 =item values
 
-Array of multiple values, one must match to fullfill the condition
+Array of multiple values, one must match to fulfill the condition
 
 =item not
 
@@ -402,12 +530,42 @@ Inverts the when condition - value(s) must not match
 
 A callback subroutine-reference or fully resolved subroutine name can be
 supplied to perform complex checks. An hashref of all parameters is passed
-to the callback sub. In this case all other keys are ignored, including not.
+to the callback sub. In this case all other keys are ignored, including C<not>.
 You need to return a true value for the constraint to be applied or a false
 value to not apply it.
 
+The callback subroutine receives 2 arguments:
+
+=over 8
+
+=item 1
+
+C<$params> (hashref of all submitted parameters)
+
+=item 2
+
+C<$constraint> (the Constraint object)
+
 =back
 
+=back
+
+=head1 EXPERIMENTAL METHODS
+
+=head2 fetch_error_message
+
+Return value: $string
+
+Attempt to return the error message that would be used if this constraint
+generated an error.
+
+This will generally be correct for simple constraints with a fixed message or
+which use a placeholder from a known value, such as
+L<HTML::FormFu::Constraint::Min/min>.
+This will generally C<not> return the correct message for constraints which
+use L<HTML::FormFu::Role::Constraint::Others/others>, where the field with an
+error is not known without actually fully processing a form submission.
+
 =head1 CORE CONSTRAINTS
 
 =over
@@ -444,6 +602,8 @@ value to not apply it.
 
 =item L<HTML::FormFu::Constraint::Integer>
 
+=item L<HTML::FormFu::Constraint::JSON>
+
 =item L<HTML::FormFu::Constraint::Length>
 
 =item L<HTML::FormFu::Constraint::MaxLength>
@@ -462,8 +622,6 @@ value to not apply it.
 
 =item L<HTML::FormFu::Constraint::Range>
 
-=item L<HTML::FormFu::Constraint::reCAPTCHA>
-
 =item L<HTML::FormFu::Constraint::Regex>
 
 =item L<HTML::FormFu::Constraint::Required>
@@ -476,6 +634,14 @@ value to not apply it.
 
 =back
 
+=head1 NON-CORE CONSTRAINTS AVAILABLE ON CPAN
+
+=over
+
+=item L<HTML::FormFu::Constraint::reCAPTCHA>
+
+=back
+
 =head1 CAVEATS
 
 See L<HTML::FormFu::Element::Repeatable/"Unsupported Constraints">
@@ -494,4 +660,15 @@ Sebastian Riedel, C<sri@oook.de>.
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
