@@ -1,21 +1,19 @@
-package HTML::FormFu::Constraint::DateTime;
-
 use strict;
-use base 'HTML::FormFu::Constraint';
-use MRO::Compat;
-use mro 'c3';
+
+package HTML::FormFu::Constraint::DateTime;
+$HTML::FormFu::Constraint::DateTime::VERSION = '2.07';
+# ABSTRACT: DateTime constraint
+
+use Moose;
+extends 'HTML::FormFu::Constraint';
 
 use DateTime::Format::Builder;
 
-__PACKAGE__->mk_item_accessors(qw( _builder ));
-
-sub new {
-    my $self = shift->next::method(@_);
-
-    $self->_builder( DateTime::Format::Builder->new );
-
-    return $self;
-}
+has _builder => (
+    is      => 'rw',
+    default => sub { DateTime::Format::Builder->new },
+    lazy    => 1,
+);
 
 sub parser {
     my $self = shift;
@@ -38,21 +36,31 @@ sub constrain_value {
 sub clone {
     my $self = shift;
 
-    my $clone = $self->next::method(@_);
+    my $clone = $self->SUPER::clone(@_);
 
     $clone->_builder( $self->_builder->clone );
 
     return $clone;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Constraint::DateTime - DateTime constraint
 
+=head1 VERSION
+
+version 2.07
+
 =head1 SYNOPSIS
 
     ---
@@ -61,9 +69,9 @@ HTML::FormFu::Constraint::DateTime - DateTime constraint
         name: start_date
         constraints:
           - type: DateTime
-            parser: 
+            parser:
               strptime: '%d-%m-%Y'
-      
+
       - type: Text
         name: end_time
         constraints:
@@ -97,7 +105,7 @@ Ensure input can later be inflated to a DateTime object.
 
 Arguments: \%args
 
-Required. Define the expected input string, so L<DateTime::Format::Builder> 
+Required. Define the expected input string, so L<DateTime::Format::Builder>
 knows how to turn it into a L<DateTime> object.
 
 Accepts arguments to be passed to L<DateTime::Format::Builder/parser>.
@@ -111,4 +119,15 @@ Carl Franks, C<cfranks@cpan.org>
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
