@@ -1,13 +1,19 @@
-package HTML::FormFu::Constraint::Equal;
-
 use strict;
-use base 'HTML::FormFu::Constraint::_others';
+
+package HTML::FormFu::Constraint::Equal;
+$HTML::FormFu::Constraint::Equal::VERSION = '2.07';
+# ABSTRACT: Multi-field Equality Constraint
+
+use Moose;
+extends 'HTML::FormFu::Constraint';
+
+with 'HTML::FormFu::Role::Constraint::Others';
 
 use HTML::FormFu::Util qw(
     DEBUG_CONSTRAINTS
     debug
 );
-use List::MoreUtils qw( all );
+use List::Util 1.33 qw( all );
 
 our $EMPTY_STR = q{};
 
@@ -36,7 +42,16 @@ sub process {
 
         my $ok = _values_eq( $value, $other_value );
 
-        if ( $self->not() ? $ok : !$ok ) {
+        if ( $self->not ) {
+            if ( $value eq $EMPTY_STR ) {
+
+                # no error if both values are empty and not(1) is set
+            }
+            elsif ($ok) {
+                push @failed, $name;
+            }
+        }
+        elsif ( !$ok ) {
             push @failed, $name;
         }
 
@@ -45,12 +60,15 @@ sub process {
 
     # special case for $self->not()
     # no errors if all values are empty
-    if ( $self->not() && all { !defined || $_ eq $EMPTY_STR } values %values ) {
+    if (   $self->not
+        && $value eq $EMPTY_STR
+        && all { !defined || $_ eq $EMPTY_STR } values %values )
+    {
         return;
     }
 
-    return $self->mk_errors( {
-            pass => @failed ? 0 : 1,
+    return $self->mk_errors(
+        {   pass   => @failed ? 0 : 1,
             failed => \@failed,
             names  => [ $self->nested_name, @names ],
         } );
@@ -95,14 +113,24 @@ sub _localize_args {
     return $self->parent->label;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Constraint::Equal - Multi-field Equality Constraint
 
+=head1 VERSION
+
+version 2.07
+
 =head1 SYNOPSIS
 
     - type: Password
@@ -115,13 +143,13 @@ HTML::FormFu::Constraint::Equal - Multi-field Equality Constraint
 
 =head1 DESCRIPTION
 
-All fields named in L<HTML::FormFu::Constraint::_others/others> must have an equal value to the field this 
+All fields named in L<HTML::FormFu::Role::Constraint::Others/others> must have an equal value to the field this
 constraint is attached to.
 
 =head1 SEE ALSO
 
-Is a sub-class of, and inherits methods from  
-L<HTML::FormFu::Constraint::_others>, L<HTML::FormFu::Constraint>
+Is a sub-class of, and inherits methods from
+L<HTML::FormFu::Role::Constraint::Others>, L<HTML::FormFu::Constraint>
 
 L<HTML::FormFu>
 
@@ -134,4 +162,15 @@ Carl Franks C<cfranks@cpan.org>
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
