@@ -1,7 +1,11 @@
-package HTML::FormFu::Constraint::MaxRange;
-
 use strict;
-use base 'HTML::FormFu::Constraint::Range';
+
+package HTML::FormFu::Constraint::MaxRange;
+$HTML::FormFu::Constraint::MaxRange::VERSION = '2.07';
+# ABSTRACT: Maximum Value Constraint
+
+use Moose;
+extends 'HTML::FormFu::Constraint::Range';
 
 sub _localize_args {
     my ($self) = @_;
@@ -9,19 +13,29 @@ sub _localize_args {
     return $self->max;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Constraint::MaxRange - Maximum Value Constraint
 
+=head1 VERSION
+
+version 2.07
+
 =head1 DESCRIPTION
 
 Checks the input value is equal to or less than a maximum value.
 
-Overrides L<HTML::FormFu::Constraint/localize_args>, so that the value of 
+Overrides L<HTML::FormFu::Constraint/localize_args>, so that the value of
 L</maximum> is passed as an argument to L<localize|HTML::FormFu/localize>.
 
 This constraint doesn't honour the C<not()> value.
@@ -52,4 +66,15 @@ Carl Franks C<cfranks@cpan.org>
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
