@@ -1,14 +1,19 @@
-package HTML::FormFu::Deflator::CompoundDateTime;
-
 use strict;
-use base 'HTML::FormFu::Deflator';
+
+package HTML::FormFu::Deflator::CompoundDateTime;
+$HTML::FormFu::Deflator::CompoundDateTime::VERSION = '2.07';
+# ABSTRACT: CompoundDateTime deflator
+
+use Moose;
+use MooseX::Attribute::Chained;
+extends 'HTML::FormFu::Deflator';
 
 use HTML::FormFu::Constants qw( $EMPTY_STR );
 use DateTime;
-use List::MoreUtils qw( none );
+use List::Util 1.33 qw( none );
 use Carp qw( croak );
 
-__PACKAGE__->mk_accessors(qw( field_order ));
+has field_order => ( is => 'rw', traits => ['Chained'] );
 
 my @known_fields = qw( year month day hour minute second nanosecond time_zone );
 
@@ -49,31 +54,41 @@ sub deflator {
     return;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Deflator::CompoundDateTime - CompoundDateTime deflator
 
+=head1 VERSION
+
+version 2.07
+
 =head1 SYNOPSIS
 
     ---
     element:
       - type: Multi
         name: date
-        
+
         elements:
           - name: day
           - name: month
           - name: year
-        
+
         deflator:
           - type: CompoundDateTime
 
     # set the default
-    
+
     $form->get_field('date')->default( $datetime );
 
 =head1 DESCRIPTION
@@ -110,20 +125,20 @@ By default, expects the field names to be any of the following:
 
 Arguments: \@order
 
-If your field names don't follow the convention listed above, you must 
-provide an arrayref containing the above names, in the order they correspond 
+If your field names don't follow the convention listed above, you must
+provide an arrayref containing the above names, in the order they correspond
 with your own fields.
 
     ---
     element:
       - type: Multi
         name: date
-        
+
         elements:
           - name: m
           - name: d
           - name: y
-        
+
         deflator:
           - type: CompoundDateTime
             field_order:
@@ -140,4 +155,15 @@ Carl Franks
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
