@@ -1,33 +1,41 @@
-package HTML::FormFu::Element::Block;
-
 use strict;
-use base 'HTML::FormFu::Element';
-use MRO::Compat;
-use mro 'c3';
+
+package HTML::FormFu::Element::Block;
+$HTML::FormFu::Element::Block::VERSION = '2.07';
+# ABSTRACT: Block element
+
+use Moose;
+use MooseX::Attribute::Chained;
+
+extends 'HTML::FormFu::Element';
+
+with 'HTML::FormFu::Role::CreateChildren',
+    'HTML::FormFu::Role::GetProcessors',
+    'HTML::FormFu::Role::ContainsElements',
+    'HTML::FormFu::Role::ContainsElementsSharedWithField',
+    'HTML::FormFu::Role::FormAndBlockMethods',
+    'HTML::FormFu::Role::FormBlockAndFieldMethods';
 
 use HTML::FormFu::Constants qw( $EMPTY_STR );
-use HTML::FormFu::ObjectUtil qw( :FORM_AND_BLOCK );
 use HTML::FormFu::Util qw( _get_elements xml_escape process_attrs );
-use Carp qw( croak );
 use Clone ();
-use List::MoreUtils qw( uniq );
+use List::Util 1.45 qw( uniq );
+use Carp qw( croak );
 
-__PACKAGE__->mk_item_accessors( qw(
-        tag                         _elements
-        nested_name                 original_nested_name
-        auto_block_id
-) );
+has tag                  => ( is => 'rw', traits => ['Chained'] );
+has nested_name          => ( is => 'rw', traits => ['Chained'] );
+has original_nested_name => ( is => 'rw', traits => ['Chained'] );
+has auto_block_id        => ( is => 'rw', traits => ['Chained'] );
+
+has _elements => (
+    is      => 'rw',
+    default => sub { [] },
+    lazy    => 1,
+    isa     => 'ArrayRef',
+);
 
 __PACKAGE__->mk_output_accessors(qw( content ));
 
-__PACKAGE__->mk_inherited_accessors( qw(
-        auto_id auto_label auto_error_class auto_error_message
-        auto_constraint_class auto_inflator_class auto_validator_class
-        auto_transformer_class render_processed_value force_errors
-        repeatable_count
-        locale
-) );
-
 *elements     = \&element;
 *constraints  = \&constraint;
 *deflators    = \&deflator;
@@ -37,17 +45,15 @@ __PACKAGE__->mk_inherited_accessors( qw(
 *transformers = \&transformer;
 *plugins      = \&plugin;
 
-sub new {
-    my $self = shift->next::method(@_);
+after BUILD => sub {
+    my ( $self, $args ) = @_;
 
-    $self->_elements( [] );
-    $self->default_args( {} );
     $self->filename('block');
     $self->tag('div');
     $self->is_block(1);
 
-    return $self;
-}
+    return;
+};
 
 sub _single_plugin {
     my ( $self, $arg ) = @_;
@@ -125,8 +131,8 @@ sub render_data {
 sub render_data_non_recursive {
     my ( $self, $args ) = @_;
 
-    my $render = $self->next::method( {
-            tag     => $self->tag,
+    my $render = $self->SUPER::render_data_non_recursive(
+        {   tag     => $self->tag,
             content => xml_escape( $self->content ),
             $args ? %$args : (),
         } );
@@ -146,9 +152,7 @@ sub prepare_id {
             ? $self->form->id
             : $EMPTY_STR;
 
-        my %string = (
-            f => $form_name,
-        );
+        my %string = ( f => $form_name, );
 
         my $id = $self->auto_block_id;
         $id =~ s/%([f])/$string{$1}/g;
@@ -185,7 +189,12 @@ sub string {
     }
 
     if ( defined $render->{legend} ) {
-        $html .= sprintf "\n<legend>%s</legend>", $render->{legend};
+        $html .=
+            sprintf "\n<legend%s>%s</legend>",
+            defined( $render->{legend_attributes} )
+            ? process_attrs( $render->{legend_attributes} )
+            : '',
+            $render->{legend};
     }
 
     # block template
@@ -220,8 +229,8 @@ sub string {
 sub start {
     my ($self) = @_;
 
-    return $self->tt( {
-            filename    => 'start_block',
+    return $self->tt(
+        {   filename    => 'start_block',
             render_data => $self->render_data_non_recursive,
         } );
 }
@@ -229,8 +238,8 @@ sub start {
 sub end {
     my ($self) = @_;
 
-    return $self->tt( {
-            filename    => 'end_block',
+    return $self->tt(
+        {   filename    => 'end_block',
             render_data => $self->render_data_non_recursive,
         } );
 }
@@ -238,34 +247,44 @@ sub end {
 sub clone {
     my $self = shift;
 
-    my $clone = $self->next::method(@_);
+    my $clone = $self->SUPER::clone(@_);
 
     $clone->_elements( [ map { $_->clone } @{ $self->_elements } ] );
 
     map { $_->parent($clone) } @{ $clone->_elements };
 
-    $clone->default_args( Clone::clone $self->default_args );
+    $clone->default_args( Clone::clone( $self->default_args ) );
 
     return $clone;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Element::Block - Block element
 
+=head1 VERSION
+
+version 2.07
+
 =head1 SYNOPSIS
 
     ---
-    elements: 
+    elements:
       - type: Block
-        elements: 
+        elements:
           - type: Text
             name: foo
-    
+
       - type: Block
         tag: span
         content: Whatever
@@ -284,21 +303,21 @@ Default Value: 'div'
 
 =head2 content
 
-If L</content> is set, it is used as the block's contents, and any attached 
+If L</content> is set, it is used as the block's contents, and any attached
 elements are ignored.
 
 =head2 content_xml
 
 Arguments: $string
 
-If you don't want the content to be XML-escaped, use the L</content_xml> 
+If you don't want the content to be XML-escaped, use the L</content_xml>
 method instead of L</content>.
 
 =head2 content_loc
 
 Arguments: $localization_key
 
-To set the content to a localized string, set L</content_loc> to a key in 
+To set the content to a localized string, set L</content_loc> to a key in
 your L10N file instead of using L</content>.
 
 =head2 elements
@@ -357,6 +376,10 @@ See L<HTML::FormFu/transformers> for details.
 
 See L<HTML::FormFu/transformer> for details.
 
+=head2 auto_datalist_id
+
+See L<HTML::FormFu/auto_datalist_id> for details.
+
 =head1 CSS CLASSES
 
 =head2 auto_id
@@ -382,6 +405,10 @@ Unlike most other auto_* methods, this is not an 'inherited accessor'.
 
 See L<HTML::FormFu/auto_label> for details.
 
+=head2 auto_error_field_class
+
+See L<HTML::FormFu/auto_error_field_class> for details.
+
 =head2 auto_error_class
 
 See L<HTML::FormFu/auto_error_class> for details.
@@ -406,6 +433,10 @@ See L<HTML::FormFu/auto_validator_class> for details.
 
 See L<HTML::FormFu/auto_transformer_class> for details.
 
+=head2 default_args
+
+See L<HTML::FormFu/default_args> for details.
+
 =head1 RENDERING
 
 =head2 start
@@ -498,6 +529,12 @@ Is a sub-class of, and inherits methods from L<HTML::FormFu::Element>
 
 L<HTML::FormFu>
 
+=head1 REMOVED METHODS
+
+=head2 element_defaults
+
+Has been removed; use L</default_args> instead.
+
 =head1 AUTHOR
 
 Carl Franks, C<cfranks@cpan.org>
@@ -507,4 +544,15 @@ Carl Franks, C<cfranks@cpan.org>
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
