@@ -1,23 +1,29 @@
-package HTML::FormFu::Element::Checkbox;
-
 use strict;
-use base 'HTML::FormFu::Element::_Input';
-use MRO::Compat;
-use mro 'c3';
+
+package HTML::FormFu::Element::Checkbox;
+$HTML::FormFu::Element::Checkbox::VERSION = '2.07';
+# ABSTRACT: Checkbox form field
+
+use Moose;
+
+extends 'HTML::FormFu::Element';
+
+with 'HTML::FormFu::Role::Element::Input';
 
 use HTML::FormFu::Constants qw( $EMPTY_STR );
 
 __PACKAGE__->mk_output_accessors(qw( default ));
 
-sub new {
-    my $self = shift->next::method(@_);
+after BUILD => sub {
+    my ( $self, $args ) = @_;
 
     $self->field_type('checkbox');
-    $self->reverse_multi(1);
     $self->value(1);
 
-    return $self;
-}
+    $self->multi_layout( [ 'field', 'label', ] );
+
+    return;
+};
 
 sub process_value {
     my ( $self, $input ) = @_;
@@ -40,6 +46,10 @@ sub prepare_attrs {
         ? $self->get_nested_hash_value( $form->input, $self->nested_name )
         : undef;
 
+    if ( defined $value and ref $value eq 'ARRAY' ) {
+        $value = $original if grep { $_ eq $original } @$value;
+    }
+
     if (   $submitted
         && defined $value
         && defined $original
@@ -60,19 +70,29 @@ sub prepare_attrs {
         $render->{attributes}{checked} = 'checked';
     }
 
-    $self->next::method($render);
+    $self->SUPER::prepare_attrs($render);
 
     return;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Element::Checkbox - Checkbox form field
 
+=head1 VERSION
+
+version 2.07
+
 =head1 SYNOPSIS
 
     my $e = $form->element( Checkbox => 'foo' );
@@ -89,17 +109,19 @@ Default Value: 1
 
 =head2 default_empty_value
 
-Inherited. See L<HTML::FormFu::Element::_Field/default_empty_value> for details.
+Inherited. See L<HTML::FormFu::Role::Element::Field/default_empty_value> for details.
 
-=head2 reverse_multi
+=head2 multi_layout
 
-Overrides the default value, so it's C<true>.
+Overrides the default value of
+L<multi_layout|HTML::FormFu::Role::Element::Field/multi_layout>
+to swap the C<field> and C<label> around.
 
 =head1 SEE ALSO
 
-Is a sub-class of, and inherits methods from 
-L<HTML::FormFu::Element::_Input>, 
-L<HTML::FormFu::Element::_Field>, 
+Is a sub-class of, and inherits methods from
+L<HTML::FormFu::Role::Element::Input>,
+L<HTML::FormFu::Role::Element::Field>,
 L<HTML::FormFu::Element>
 
 L<HTML::FormFu>
@@ -113,4 +135,15 @@ Carl Franks, C<cfranks@cpan.org>
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
