@@ -1,29 +1,45 @@
-package HTML::FormFu::Element::Checkboxgroup;
-
 use strict;
-use base 'HTML::FormFu::Element::_Group';
-use MRO::Compat;
-use mro 'c3';
+
+package HTML::FormFu::Element::Checkboxgroup;
+$HTML::FormFu::Element::Checkboxgroup::VERSION = '2.07';
+# ABSTRACT: Group of checkbox form fields
+
+use Moose;
+use MooseX::Attribute::Chained;
+extends 'HTML::FormFu::Element';
+
+with 'HTML::FormFu::Role::Element::Group';
 
 use HTML::FormFu::Constants qw( $EMPTY_STR );
 use HTML::FormFu::Util qw( append_xml_attribute process_attrs );
-use List::MoreUtils qw( any );
+use List::Util 1.33 qw( any );
 
-__PACKAGE__->mk_item_accessors(qw/ reverse_group input_type /);
+has input_type => (
+    is      => 'rw',
+    default => 'checkbox',
+    lazy    => 1,
+    traits  => ['Chained'],
+);
 
-sub new {
-    my $self = shift->next::method(@_);
+has reverse_group => (
+    is     => 'rw',
+    traits => ['Chained'],
+);
 
-    $self->filename('input');
-    $self->field_filename('checkboxgroup_tag');
+after BUILD => sub {
+    my ( $self, $args ) = @_;
+
+    $self->layout_field_filename('field_layout_checkboxgroup_field');
     $self->label_tag('legend');
     $self->container_tag('fieldset');
     $self->multi_value(1);
     $self->reverse_group(1);
     $self->input_type('checkbox');
 
-    return $self;
-}
+    $self->layout( [ 'label', 'errors', 'field', 'comment', 'javascript', ] );
+
+    return;
+};
 
 sub prepare_id {
     my ( $self, $render ) = @_;
@@ -58,6 +74,7 @@ sub _prepare_id {
         my $id = $self->auto_id;
         $id =~ s/%([fn])/$string{$1}/g;
         $id =~ s/%c/ ++$$count_ref /gex;
+        $id =~ s/%v/ $option->{value} /gex;
 
         if ( defined( my $count = $self->repeatable_count ) ) {
             $id =~ s/%r/$count/g;
@@ -112,8 +129,8 @@ sub _prepare_attrs {
 sub render_data_non_recursive {
     my ( $self, $args ) = @_;
 
-    my $render = $self->next::method( {
-            field_filename => $self->field_filename,
+    my $render = $self->SUPER::render_data_non_recursive(
+        {   field_filename => $self->field_filename,
             reverse_group  => $self->reverse_group,
             input_type     => $self->input_type,
             $args ? %$args : (),
@@ -141,6 +158,10 @@ sub _string_field {
                 process_attrs( $option->{attributes} ),
                 ;
 
+            if ( defined $option->{label} ) {
+                $html .= sprintf "<p>%s</p>\n", $option->{label};
+            }
+
             for my $item ( @{ $option->{group} } ) {
                 $html .= sprintf
                     "<span%s>\n",
@@ -175,8 +196,7 @@ sub _string_field {
         else {
             $html .= sprintf
                 "<span%s>\n",
-                process_attrs( $option->{container_attributes} )
-                ;
+                process_attrs( $option->{container_attributes} );
 
             my $label = sprintf
                 "<label%s>%s</label>\n",
@@ -208,14 +228,24 @@ sub _string_field {
     return $html;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Element::Checkboxgroup - Group of checkbox form fields
 
+=head1 VERSION
+
+version 2.07
+
 =head1 SYNOPSIS
 
 YAML config:
@@ -233,29 +263,31 @@ YAML config:
 
 Convenient to use group of checkbox fields.
 
-Use the same syntax as you would to create a Select element optgroup to 
-create Checkboxgroup sub-groups, see L<HTML::FormFu::Element::_Group/options> 
+Use the same syntax as you would to create a Select element optgroup to
+create Checkboxgroup sub-groups, see L<HTML::FormFu::Role::Element::Group/options>
 for details.
 
 =head1 METHODS
 
 =head2 options
 
-See L<HTML::FormFu::Element::_Group/options>.
+See L<HTML::FormFu::Role::Element::Group/options>.
 
 =head2 values
 
-See L<HTML::FormFu::Element::_Group/values>.
+See L<HTML::FormFu::Role::Element::Group/values>.
 
 =head2 value_range
 
-See L<HTML::FormFu::Element::_Group/value_range>.
+See L<HTML::FormFu::Role::Element::Group/value_range>.
 
 =head2 auto_id
 
-In addition to the substitutions documented by L<HTML::FormFu/auto_id>, 
-C<%c> will be replaced by an incremented integer, to ensure there are 
-no duplicated ID's.
+In addition to the substitutions documented by L<HTML::FormFu/auto_id>,
+C<%c> will be replaced by an incremented integer, to ensure there are
+no duplicated ID's, and C<%v> will be replaced by the item's value to
+allow multiple elements with the same name to coexist, and their labels
+to correctly select the appropriate item.
 
     ---
     elements:
@@ -277,9 +309,9 @@ Default Value: C<true>
 
 =head1 SEE ALSO
 
-Is a sub-class of, and inherits methods from 
-L<HTML::FormFu::Element::_Group>, 
-L<HTML::FormFu::Element::_Field>, 
+Is a sub-class of, and inherits methods from
+L<HTML::FormFu::Role::Element::Group>,
+L<HTML::FormFu::Role::Element::Field>,
 L<HTML::FormFu::Element>
 
 L<HTML::FormFu>
@@ -293,4 +325,15 @@ Carl Franks, C<cfranks@cpan.org>
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
