@@ -1,12 +1,18 @@
-package HTML::FormFu::Element::ComboBox;
 use strict;
-use base 'HTML::FormFu::Element::Multi';
-use MRO::Compat;
-use mro 'c3';
 
-use HTML::FormFu::Element::_Group qw( _process_options_from_model );
+package HTML::FormFu::Element::ComboBox;
+$HTML::FormFu::Element::ComboBox::VERSION = '2.07';
+# ABSTRACT: Select / Text hybrid
+
+use Moose;
+use MooseX::Attribute::Chained;
+extends 'HTML::FormFu::Element::Multi';
+
+with 'HTML::FormFu::Role::Element::ProcessOptionsFromModel';
+
 use HTML::FormFu::Util qw( _filter_components _parse_args );
-use List::MoreUtils qw( any );
+use List::Util 1.33 qw( any );
+use Moose::Util qw( apply_all_roles );
 
 our @DEFER_TO_SELECT = qw(
     empty_first
@@ -15,12 +21,12 @@ our @DEFER_TO_SELECT = qw(
     value_range
 );
 
-__PACKAGE__->mk_accessors(
-    @DEFER_TO_SELECT,
-    qw(
-        select
-        text
-        ) );
+for my $name (@DEFER_TO_SELECT) {
+    has $name => ( is => 'rw', traits => ['Chained'] );
+}
+
+has select => ( is => 'rw', traits => ['Chained'], default => sub { {} } );
+has text   => ( is => 'rw', traits => ['Chained'], default => sub { {} } );
 
 *default = \&value;
 
@@ -45,23 +51,20 @@ for my $method ( qw(
 
     my $name = __PACKAGE__ . "::get_${method}s";
 
+    ## no critic (ProhibitNoStrict);
     no strict 'refs';
 
     *{$name} = $sub;
 }
 
-sub new {
-    my $self = shift->next::method(@_);
+after BUILD => sub {
+    my ( $self, $args ) = @_;
 
     $self->multi_value(1);
     $self->empty_first(1);
 
-    $self->select( { type => '_MultiSelect', } );
-
-    $self->text( { type => '_MultiText', } );
-
-    return $self;
-}
+    return;
+};
 
 sub options {
     my ( $self, @args ) = @_;
@@ -125,13 +128,13 @@ sub _combobox_defaults {
     my ($self) = @_;
 
     if ( defined( my $default = $self->default ) ) {
-        
+
         if ( !$self->form->submitted || $self->render_processed_value ) {
             for my $deflator ( @{ $self->_deflators } ) {
                 $default = $deflator->process($default);
             }
         }
-        
+
         my $select_options = $self->_elements->[0]->options;
 
         if ( $default ne ''
@@ -156,11 +159,14 @@ sub _add_select {
 
     my $select_name = _build_field_name( $self, 'select' );
 
-    my $select_element = $self->element( {
-            type => $select->{type},
+    my $select_element = $self->element(
+        {   type => 'Select',
             name => $select_name,
         } );
 
+    apply_all_roles( $select_element,
+        'HTML::FormFu::Role::Element::MultiElement' );
+
     for my $method (@DEFER_TO_SELECT) {
         if ( defined( my $value = $self->$method ) ) {
             $select_element->$method($value);
@@ -188,11 +194,14 @@ sub _add_text {
 
     my $text_name = _build_field_name( $self, 'text' );
 
-    my $text_element = $self->element( {
-            type => $text->{type},
+    my $text_element = $self->element(
+        {   type => 'Text',
             name => $text_name,
         } );
 
+    apply_all_roles( $text_element,
+        'HTML::FormFu::Role::Element::MultiElement' );
+
     if ( defined( my $default = $text->{default} ) ) {
         $text_element->default($default);
     }
@@ -200,6 +209,22 @@ sub _add_text {
     return;
 }
 
+sub get_select_field_nested_name {
+    my ($self) = @_;
+
+    my $select_name = _build_field_name( $self, 'select' );
+
+    return $self->get_element( { name => $select_name } )->nested_name;
+}
+
+sub get_text_field_nested_name {
+    my ($self) = @_;
+
+    my $text_name = _build_field_name( $self, 'text' );
+
+    return $self->get_element( { name => $text_name } )->nested_name;
+}
+
 sub _build_field_name {
     my ( $self, $type ) = @_;
 
@@ -223,17 +248,14 @@ sub process {
 
     $self->_add_elements;
 
-    return $self->next::method(@args);
+    return $self->SUPER::process(@args);
 }
 
 sub process_input {
     my ( $self, $input ) = @_;
 
-    my $select_name = _build_field_name( $self, 'select' );
-    my $text_name   = _build_field_name( $self, 'text' );
-
-    $select_name = $self->get_element( { name => $select_name } )->nested_name;
-    $text_name   = $self->get_element( { name => $text_name } )->nested_name;
+    my $select_name = $self->get_select_field_nested_name;
+    my $text_name   = $self->get_text_field_nested_name;
 
     my $select_value = $self->get_nested_hash_value( $input, $select_name );
     my $text_value   = $self->get_nested_hash_value( $input, $text_name );
@@ -243,11 +265,11 @@ sub process_input {
         );
     }
     elsif ( defined $select_value && length $select_value ) {
-        $self->set_nested_hash_value( $input, $self->nested_name, $select_value,
-        );
+        $self->set_nested_hash_value( $input, $self->nested_name,
+            $select_value, );
     }
 
-    return $self->next::method($input);
+    return $self->SUPER::process_input($input);
 }
 
 sub render_data {
@@ -257,22 +279,32 @@ sub render_data {
 sub render_data_non_recursive {
     my ( $self, $args ) = @_;
 
-    my $render = $self->next::method( {
-            elements => [ map { $_->render_data } @{ $self->_elements } ],
+    my $render = $self->SUPER::render_data_non_recursive(
+        {   elements => [ map { $_->render_data } @{ $self->_elements } ],
             $args ? %$args : (),
         } );
 
     return $render;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Element::ComboBox - Select / Text hybrid
 
+=head1 VERSION
+
+version 2.07
+
 =head1 SYNOPSIS
 
     ---
@@ -284,14 +316,13 @@ HTML::FormFu::Element::ComboBox - Select / Text hybrid
           - yes
           - no
 
-
 =head1 DESCRIPTION
 
 Creates a L<multi|HTML::FormFu::Element::Multi> element containing a Select
 field and a Text field.
 
 A ComboBox element named C<foo> would result in a Select menu named
-C<foo_select> and a Text field named C<foo_text>. The names can instead be 
+C<foo_select> and a Text field named C<foo_text>. The names can instead be
 overridden by the C<name> value in L</select> and L</text>.
 
 If a value is submitted for the Text field, this will be used in preference
@@ -310,23 +341,23 @@ selected. Otherwise, the Text field will use the value as its default.
 
 =head2 options
 
-See L<HTML::FormFu::Element::_Group/options> for details.
+See L<HTML::FormFu::Role::Element::Group/options> for details.
 
 =head2 values
 
-See L<HTML::FormFu::Element::_Group/values> for details.
+See L<HTML::FormFu::Role::Element::Group/values> for details.
 
 =head2 value_range
 
-See L<HTML::FormFu::Element::_Group/value_range> for details.
+See L<HTML::FormFu::Role::Element::Group/value_range> for details.
 
 =head2 empty_first
 
-See L<HTML::FormFu::Element::_Group/empty_first> for details.
+See L<HTML::FormFu::Role::Element::Group/empty_first> for details.
 
 =head2 empty_first_label
 
-See L<HTML::FormFu::Element::_Group/empty_first_label> for details.
+See L<HTML::FormFu::Role::Element::Group/empty_first_label> for details.
 
 =head2 select
 
@@ -350,27 +381,27 @@ Override the auto-generated name of the select menu.
 
 =head1 CAVEATS
 
-Although this element inherits from L<HTML::FormFu::Element::Block>, its 
-behaviour for the methods 
-L<filter/filters|HTML::FormFu/filters>, 
-L<constraint/constraints|HTML::FormFu/constraints>, 
-L<inflator/inflators|HTML::FormFu/inflators>, 
-L<validator/validators|HTML::FormFu/validators> and 
-L<transformer/transformers|HTML::FormFu/transformers> is more like that of 
-a L<field element|HTML::FormFu::Element::_Field>, meaning all processors are 
+Although this element inherits from L<HTML::FormFu::Element::Block>, its
+behaviour for the methods
+L<filterE<sol>filters|HTML::FormFu/filters>,
+L<constraintE<sol>constraints|HTML::FormFu/constraints>,
+L<inflatorE<sol>inflators|HTML::FormFu/inflators>,
+L<validatorE<sol>validators|HTML::FormFu/validators> and
+L<transformerE<sol>transformers|HTML::FormFu/transformers> is more like that of
+a L<field element|HTML::FormFu::Role::Element::Field>, meaning all processors are
 added directly to the date element, not to its child elements.
 
-This element's L<get_elements|HTML::FormFu/get_elements> and 
-L<get_all_elements|HTML::FormFu/get_all_elements> are inherited from 
-L<HTML::FormFu::Element::Block>, and so have the same behaviour. However, it 
+This element's L<get_elements|HTML::FormFu/get_elements> and
+L<get_all_elements|HTML::FormFu/get_all_elements> are inherited from
+L<HTML::FormFu::Element::Block>, and so have the same behaviour. However, it
 overrides the C<get_fields|HTML::FormFu/get_fields> method, such that it
 returns both itself and its child elements.
 
 =head1 SEE ALSO
 
-Is a sub-class of, and inherits methods from 
-L<HTML::FormFu::Element::Multi>, 
-L<HTML::FormFu::Element::Block>, 
+Is a sub-class of, and inherits methods from
+L<HTML::FormFu::Element::Multi>,
+L<HTML::FormFu::Element::Block>,
 L<HTML::FormFu::Element>
 
 L<HTML::FormFu>
@@ -384,4 +415,15 @@ Carl Franks, C<cfranks@cpan.org>
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
