@@ -1,28 +1,43 @@
-package HTML::FormFu::Element::File;
-
 use strict;
-use base 'HTML::FormFu::Element::_Input';
-use MRO::Compat;
-use mro 'c3';
 
-sub new {
-    my $self = shift->next::method(@_);
+package HTML::FormFu::Element::File;
+$HTML::FormFu::Element::File::VERSION = '2.07';
+# ABSTRACT: File upload form field
+
+use Moose;
+
+extends 'HTML::FormFu::Element';
+
+with 'HTML::FormFu::Role::Element::Input';
+
+after BUILD => sub {
+    my $self = shift;
 
     $self->field_type('file');
 
     $self->form->enctype('multipart/form-data');
 
-    return $self;
-}
+    return;
+};
+
+__PACKAGE__->meta->make_immutable;
 
 1;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Element::File - File upload form field
 
+=head1 VERSION
+
+version 2.07
+
 =head1 SYNOPSIS
 
     ---
@@ -31,14 +46,14 @@ HTML::FormFu::Element::File - File upload form field
       name: photo
 
     my $photo = $form->param('photo');
-    
+
     my $blob = $photo->slurp;
 
 =head1 DESCRIPTION
 
 File upload form field.
 
-See the documentation relevant to the L<query_type|HTML::FormFu/query_type> 
+See the documentation relevant to the L<query_type|HTML::FormFu/query_type>
 you're using:
 
 =over
@@ -55,9 +70,9 @@ you're using:
 
 =head1 SEE ALSO
 
-Is a sub-class of, and inherits methods from 
-L<HTML::FormFu::Element::_Input>, 
-L<HTML::FormFu::Element::_Field>, 
+Is a sub-class of, and inherits methods from
+L<HTML::FormFu::Role::Element::Input>,
+L<HTML::FormFu::Role::Element::Field>,
 L<HTML::FormFu::Element>
 
 L<HTML::FormFu>
@@ -71,4 +86,15 @@ Carl Franks, C<cfranks@cpan.org>
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
