@@ -1,53 +1,38 @@
-package HTML::FormFu::Element::Multi;
-
 use strict;
-use base 'HTML::FormFu::Element::Block', 'HTML::FormFu::Element::_Field';
-use MRO::Compat;
-use mro 'c3';
 
-use HTML::FormFu::Element::_Field qw( :FIELD );
+package HTML::FormFu::Element::Multi;
+$HTML::FormFu::Element::Multi::VERSION = '2.07';
+# ABSTRACT: Combine multiple fields in a single element
+
+use Moose;
+use MooseX::Attribute::Chained;
+extends 'HTML::FormFu::Element::Block';
+
+with
+    'HTML::FormFu::Role::Element::Field',
+    'HTML::FormFu::Role::Element::SingleValueField';
+
 use HTML::FormFu::Util
     qw( append_xml_attribute xml_escape process_attrs _parse_args _get_elements _filter_components );
 use Clone ();
 
-__PACKAGE__->mk_item_accessors( qw(
-        field_filename
-        label_filename
-        javascript
-        container_tag
-        label_tag
-) );
-
-__PACKAGE__->mk_output_accessors(qw( comment label value ));
-
-__PACKAGE__->mk_attrs( qw(
-        comment_attributes
-        container_attributes
-        label_attributes
-) );
-
-*default     = \&value;
-*default_xml = \&value_xml;
-*default_loc = \&value_loc;
-
-sub new {
-    my $self = shift->next::method(@_);
+after BUILD => sub {
+    my $self = shift;
 
     $self->comment_attributes(   {} );
     $self->container_attributes( {} );
     $self->label_attributes(     {} );
-    $self->filename('multi');
-    $self->label_filename('label');
+    $self->layout_field_filename('field_layout_multi_field');
     $self->label_tag('label');
 
-    return $self;
-}
+    return;
+};
 
 sub get_fields {
     my $self = shift;
     my %args = _parse_args(@_);
 
-    my $f = $self->next::method(@_);
+    my $f = $self->SUPER::get_fields(@_);
 
     unshift @$f, $self;
 
@@ -147,86 +132,78 @@ sub clear_errors {
     return;
 }
 
+sub render_data {
+    my $self = shift;
+
+    my $render = $self->SUPER::render_data(@_);
+
+    map { delete $_->{container_tag} } @{ $render->{elements} || [] };
+
+    return $render;
+}
+
 sub render_data_non_recursive {
     my $self = shift;
 
-    my $render = $self->next::method(@_);
+    my $render = $self->SUPER::render_data_non_recursive(@_);
 
     append_xml_attribute( $render->{attributes}, 'class', 'elements' );
 
     return $render;
 }
 
-sub string {
-    my ( $self, $args ) = @_;
+sub _parse_layout_field {
+    my ( $self, $render ) = @_;
 
-    $args ||= {};
-
-    my $render
-        = exists $args->{render_data}
-        ? $args->{render_data}
-        : $self->render_data_non_recursive;
-
-    # field wrapper template - start
-
-    my $html = $self->_string_field_start($render);
-
-    # multi template
-
-    $html .= sprintf "<span%s>\n", process_attrs( $render->{attributes} );
+    my @html = ( sprintf "<span%s>", process_attrs( $render->{attributes} ), );
 
     for my $elem ( @{ $self->get_elements } ) {
         my $render = $elem->render_data;
 
         next if !defined $render;
 
-        if ( $elem->reverse_multi ) {
-            $html .= $elem->_string_field($render);
+        $render->{container_tag} = undef;
 
-            if ( defined $elem->label ) {
-                $html .= sprintf "\n%s", $elem->_string_label($render);
-            }
-        }
-        else {
-            if ( defined $elem->label ) {
-                $html .= $elem->_string_label($render) . "\n";
-            }
-
-            $html .= $elem->_string_field($render);
-        }
-
-        $html .= "\n";
+        push @html,
+            $elem->string(
+            { render_data => $render, layout => $elem->multi_layout } );
     }
 
-    $html .= "</span>";
+    push @html, "</span>";
 
-    # field wrapper template - end
-
-    $html .= $self->_string_field_end($render);
-
-    return $html;
+    return join "\n", @html;
 }
 
 sub clone {
     my $self = shift;
 
-    my $clone = $self->next::method(@_);
+    my $clone = $self->SUPER::clone(@_);
 
-    $clone->comment_attributes( Clone::clone $self->comment_attributes );
-    $clone->container_attributes( Clone::clone $self->container_attributes );
-    $clone->label_attributes( Clone::clone $self->label_attributes );
+    $clone->comment_attributes( Clone::clone( $self->comment_attributes ) );
+    $clone->container_attributes( Clone::clone( $self->container_attributes ) );
+    $clone->label_attributes( Clone::clone( $self->label_attributes ) );
 
     return $clone;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Element::Multi - Combine multiple fields in a single element
 
+=head1 VERSION
+
+version 2.07
+
 =head1 SYNOPSIS
 
     my $e = $form->element( Multi => 'foo' );
@@ -235,12 +212,22 @@ HTML::FormFu::Element::Multi - Combine multiple fields in a single element
 
 Combine multiple form fields in a single logical element.
 
-=head1 METHODS
+Non-field elements cannot be added as children of the Multi element.
+
+=head1 RENDERING NOTES
+
+If the Multi element is rendered with the default 'string' render-method,
+all child fields will be rendered with the 'string' render-method, regardless
+of their L<HTML::FormFu/render_method> value.
+
+Likewise, if the Multi element is rendered with the 'tt' render-method,
+all child fields will be rendered with the 'tt' render-method, regardless of
+their L<HTML::FormFu/render_method> value.
 
 =head1 SEE ALSO
 
-Is a sub-class of, and inherits methods from 
-L<HTML::FormFu::Element::_Field>, 
+Is a sub-class of, and inherits methods from
+L<HTML::FormFu::Role::Element::Field>,
 L<HTML::FormFu::Element>
 
 L<HTML::FormFu>
@@ -254,4 +241,15 @@ Carl Franks, C<cfranks@cpan.org>
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
