@@ -1,11 +1,18 @@
-package HTML::FormFu::Filter::Regex;
-
 use strict;
-use base 'HTML::FormFu::Filter';
+
+package HTML::FormFu::Filter::Regex;
+$HTML::FormFu::Filter::Regex::VERSION = '2.07';
+# ABSTRACT: regexp-based match/replace filter
+
+use Moose;
+use MooseX::Attribute::Chained;
+extends 'HTML::FormFu::Filter';
 
 use HTML::FormFu::Constants qw( $EMPTY_STR );
 
-__PACKAGE__->mk_item_accessors(qw( match replace eval ));
+has match   => ( is => 'rw', traits => ['Chained'] );
+has replace => ( is => 'rw', traits => ['Chained'] );
+has eval    => ( is => 'rw', traits => ['Chained'] );
 
 sub filter {
     my ( $self, $value ) = @_;
@@ -25,14 +32,24 @@ sub filter {
     return $value;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Filter::Regex - regexp-based match/replace filter
 
+=head1 VERSION
+
+version 2.07
+
 =head1 SYNOPSIS
 
 The following filter would turn C<1234-5678> into C<****-****>.
@@ -49,14 +66,14 @@ Regular expression-based match / replace filter.
 
 =head2 match
 
-A regex object or string to be used in the "left-hand side" of a C<s///g> 
+A regex object or string to be used in the "left-hand side" of a C<s///g>
 regular expression.
 
 Default Value: qr/./
 
 =head2 replace
 
-A string to be used in the "right-hand side" of a C<s///g> regular 
+A string to be used in the "right-hand side" of a C<s///g> regular
 expression. The string will replace every occurrence of L</match>.
 
 Default Value: ''
@@ -79,4 +96,15 @@ Carl Franks, C<cfranks@cpan.org>
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
