@@ -1,24 +1,26 @@
-package HTML::FormFu::Inflator::DateTime;
-
 use strict;
-use base 'HTML::FormFu::Inflator';
-use MRO::Compat;
-use mro 'c3';
+
+package HTML::FormFu::Inflator::DateTime;
+$HTML::FormFu::Inflator::DateTime::VERSION = '2.07';
+# ABSTRACT: DateTime inflator
+
+use Moose;
+use MooseX::Attribute::Chained;
+extends 'HTML::FormFu::Inflator';
 
 use HTML::FormFu::Constants qw( $EMPTY_STR );
 use DateTime::Format::Builder;
 use DateTime::Format::Strptime;
 use Scalar::Util qw( reftype );
 
-__PACKAGE__->mk_item_accessors(qw( strptime time_zone _builder ));
+has strptime  => ( is => 'rw', traits => ['Chained'] );
+has time_zone => ( is => 'rw', traits => ['Chained'] );
 
-sub new {
-    my $self = shift->next::method(@_);
-
-    $self->_builder( DateTime::Format::Builder->new );
-
-    return $self;
-}
+has _builder => (
+    is      => 'rw',
+    default => sub { DateTime::Format::Builder->new },
+    lazy    => 1,
+);
 
 sub parser {
     my ( $self, $arg ) = @_;
@@ -47,7 +49,7 @@ sub inflator {
         my $strptime = $self->strptime;
         my %args;
 
-        if ( ( reftype( $strptime ) || '' ) eq 'HASH' ) {
+        if ( ( reftype($strptime) || '' ) eq 'HASH' ) {
             %args = %$strptime;
         }
         else {
@@ -77,21 +79,31 @@ sub inflator {
 sub clone {
     my $self = shift;
 
-    my $clone = $self->next::method(@_);
+    my $clone = $self->SUPER::clone(@_);
 
     $clone->_builder( $self->_builder->clone );
 
     return $clone;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Inflator::DateTime - DateTime inflator
 
+=head1 VERSION
+
+version 2.07
+
 =head1 SYNOPSIS
 
     ---
@@ -100,12 +112,12 @@ HTML::FormFu::Inflator::DateTime - DateTime inflator
         name: start_date
         inflators:
           - type: DateTime
-            parser: 
+            parser:
               strptime: '%d-%m-%Y'
             strptime:
               pattern: '%d-%b-%Y'
               locale: de
-      
+
       - type: Text
         name: end_time
         inflators:
@@ -143,7 +155,7 @@ For a corresponding deflator, see L<HTML::FormFu::Deflator::Strftime>.
 
 Arguments: \%args
 
-Required. Define the expected input string, so L<DateTime::Format::Builder> 
+Required. Define the expected input string, so L<DateTime::Format::Builder>
 knows how to inflate it into a L<DateTime> object.
 
 Accepts arguments to be passed to L<DateTime::Format::Builder/parser>.
@@ -154,7 +166,7 @@ Arguments: \%args
 
 Arguments: $string
 
-Optional. Define the format that should be used if the L<DateTime> object is 
+Optional. Define the format that should be used if the L<DateTime> object is
 stringified.
 
 =head2 time_zone
@@ -166,9 +178,9 @@ created. This is useful if the string to parse does not contain time zone
 information and you want the DateTime to be in a specific zone instead
 of the floating one (which is likely).
 
-Accepts a hashref of arguments to be passed to 
-L<DateTime::Format::Strptime/new>. Alternatively, accepts a single string 
-argument, suitable for passing to 
+Accepts a hashref of arguments to be passed to
+L<DateTime::Format::Strptime/new>. Alternatively, accepts a single string
+argument, suitable for passing to
 C<< DateTime::Format::Strptime->new( pattern => $string ) >>.
 
 =head1 AUTHOR
@@ -180,4 +192,15 @@ Carl Franks, C<cfranks@cpan.org>
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
