@@ -1,11 +1,14 @@
-package HTML::FormFu::Localize;
-
 use strict;
 
+package HTML::FormFu::Localize;
+# ABSTRACT: Localization
+$HTML::FormFu::Localize::VERSION = '2.07';
+use warnings;
+
 use HTML::FormFu::Util qw( require_class );
-use List::MoreUtils qw( any );
+use List::Util 1.33 qw( any );
 use List::MoreUtils qw( pairwise );
-use Scalar::Util qw( blessed );
+use Scalar::Util qw( weaken isweak blessed );
 use Exporter qw( import );
 use Carp qw( croak );
 
@@ -83,6 +86,16 @@ sub add_localize_object {
             localize_object     => $localize_object,
             dies_on_missing_key => $dies_on_missing_key,
             };
+
+        if ( !exists $self->{weaken_localize_object}
+            || $self->{weaken_localize_object} != 0
+            && !isweak @{ $self->{localize_data} }[-1]->{localize_object} )
+        {
+            weaken @{ $self->{localize_data} }[-1]->{localize_object};
+        }
+        else {
+            delete $self->{weaken_localize_object};
+        }
     }
 
     return $self;
@@ -90,12 +103,10 @@ sub add_localize_object {
 
 sub add_localize_object_from_class {
     my ( $self, @class ) = @_;
-    
+
+    $self->{weaken_localize_object} = 0;
     return $self->add_localize_object(
-        map {
-            $self->get_localize_object_from_class( $_ )
-        } @class
-    );
+        map { $self->get_localize_object_from_class($_) } @class );
 }
 
 sub get_localize_object_from_class {
@@ -104,7 +115,6 @@ sub get_localize_object_from_class {
     require_class($class);
 
     my $languages = $self->languages;
-    $languages = [$languages] if ref $languages ne 'ARRAY';
 
     return $class->get_handle(@$languages);
 
@@ -172,3 +182,30 @@ sub get_localize_object {
 }
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+HTML::FormFu::Localize - Localization
+
+=head1 VERSION
+
+version 2.07
+
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
