@@ -1,41 +1,17 @@
-package HTML::FormFu::Plugin;
-
 use strict;
-use MRO::Compat;
-use mro 'c3';
 
-use HTML::FormFu::Attribute qw( mk_item_accessors mk_accessors );
-use HTML::FormFu::ObjectUtil qw( populate form parent );
-use Scalar::Util qw( refaddr reftype );
-use Carp qw( croak );
+package HTML::FormFu::Plugin;
+$HTML::FormFu::Plugin::VERSION = '2.07';
+# ABSTRACT: base class for plugins
 
-__PACKAGE__->mk_item_accessors(qw( type ));
+use Moose;
+use MooseX::Attribute::Chained;
 
-sub new {
-    my $class = shift;
-    my %attrs;
-    
-    if (@_) {
-        croak "attributes argument must be a hashref"
-            if reftype( $_[0] ) ne 'HASH';
-        
-        %attrs = %{ $_[0] };
-    }
+with 'HTML::FormFu::Role::HasParent', 'HTML::FormFu::Role::Populate';
 
-    my $self = bless {}, $class;
+use HTML::FormFu::ObjectUtil qw( form parent );
 
-    for (qw( type )) {
-        croak "$_ attribute required" if !exists $attrs{$_};
-    }
-
-    if ( exists $attrs{parent} ) {
-        $self->parent( delete $attrs{parent} );
-    }
-
-    $self->populate( \%attrs );
-
-    return $self;
-}
+has type => ( is => 'rw', traits => ['Chained'] );
 
 sub pre_process { }
 
@@ -55,14 +31,24 @@ sub clone {
     return bless \%new, ref $self;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Plugin - base class for plugins
 
+=head1 VERSION
+
+version 2.07
+
 =head2 DESCRIPTION
 
 Plugins can be added to a form or any element to modify their behaviour.
@@ -76,13 +62,20 @@ Plugins can override any of the following method stubs.
 =head2 process
 
 Only plugins added to a form or a field element inheriting from
-L<HTML::FormFu::Element::_Field> will have their C<process> method run.
+L<HTML::FormFu::Role::Element::Field> will have their C<process> method run.
 
 For form plugins, is called during L<HTML::FormFu/process>, before C<process>
 is called on any elements.
 
 For field plugins, is called during the field's C<process> call.
 
+=head2 pre_process
+
+For form plugins, is called immediately after C<pre_process>
+is run on the elements.
+
+For element plugins, is called before C<pre_process> is run on form plugins.
+
 =head2 post_process
 
 For form plugins, is called immediately before L<HTML::FormFu/process>
@@ -123,4 +116,15 @@ Carl Franks, C<cfranks@cpan.org>
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
