@@ -1,9 +1,11 @@
-package HTML::FormFu::Plugin::StashValid;
-
 use strict;
-use base 'HTML::FormFu::Plugin';
-use MRO::Compat;
-use mro 'c3';
+
+package HTML::FormFu::Plugin::StashValid;
+$HTML::FormFu::Plugin::StashValid::VERSION = '2.07';
+# ABSTRACT: place valid params on form stash
+
+use Moose;
+extends 'HTML::FormFu::Plugin';
 
 sub post_process {
     my ($self) = @_;
@@ -18,14 +20,24 @@ sub post_process {
     return;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Plugin::StashValid - place valid params on form stash
 
+=head1 VERSION
+
+version 2.07
+
 =head1 SYNOPSIS
 
     # called on a form or block
@@ -38,14 +50,14 @@ HTML::FormFu::Plugin::StashValid - place valid params on form stash
     ---
     elements:
       - name: foo
-        plugins: 
+        plugins:
           - StashValid
 
 =head1 DESCRIPTION
 
 Run during the L<HTML::FormFu::Plugin/post_process> hook (called during
 L<HTML::FormFu/process>).
-If the named field(s) have a valid value after processing, that value is 
+If the named field(s) have a valid value after processing, that value is
 placed on the form stash, using the field-name as the stash-key.
 
 =head1 METHODS
@@ -67,4 +79,15 @@ Carl Franks C<cfranks@cpan.org>
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
