@@ -1,32 +1,23 @@
-package HTML::FormFu::Upload;
-
 use strict;
-use Carp qw( croak );
 
-use HTML::FormFu::Attribute qw( mk_item_accessors );
-use HTML::FormFu::ObjectUtil qw( form parent populate );
+package HTML::FormFu::Upload;
+$HTML::FormFu::Upload::VERSION = '2.07';
+# ABSTRACT: uploaded file
+
+use Moose;
+use MooseX::Attribute::Chained;
+
+with 'HTML::FormFu::Role::Populate';
+
+use HTML::FormFu::ObjectUtil qw( form parent );
 use HTML::FormFu::UploadParam;
-use Scalar::Util qw( reftype );
 
-__PACKAGE__->mk_item_accessors(qw( headers filename size type ));
+has headers  => ( is => 'rw', traits => ['Chained'] );
+has filename => ( is => 'rw', traits => ['Chained'] );
+has size     => ( is => 'rw', traits => ['Chained'] );
+has type     => ( is => 'rw', traits => ['Chained'] );
 
-sub new {
-    my $class = shift;
-    my %attrs;
-    
-    if (@_) {
-        croak "attributes argument must be a hashref"
-            if reftype( $_[0] ) ne 'HASH';
-        
-        %attrs = %{ $_[0] };
-    }
-
-    my $self = bless \%attrs, $class;
-
-    $self->populate( \%attrs );
-
-    return $self;
-}
+sub BUILD { }
 
 sub _param {
     my ( $self, $param ) = @_;
@@ -42,14 +33,38 @@ sub _param {
     return defined $self->{_param} ? $self->{_param}->param : ();
 }
 
+sub slurp {
+    my ($self) = @_;
+
+    my $fh = $self->fh;
+
+    return if !defined $fh;
+
+    binmode $fh;
+
+    local $/;
+
+    return <$fh>;
+}
+
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Upload - uploaded file
 
+=head1 VERSION
+
+version 2.07
+
 =head1 DESCRIPTION
 
 An instance is created for each uploaded file.
@@ -71,12 +86,12 @@ from L<HTML::FormFu::Upload>:
 
 =head2 parent
 
-Returns the L<field|HTML::FormFu::Element::_Field> object that the upload
+Returns the L<field|HTML::FormFu::Role::Element::Field> object that the upload
 object is associated with.
 
 =head2 form
 
-Returns the L<HTML::FormFu> object that the upload object's field is attached 
+Returns the L<HTML::FormFu> object that the upload object's field is attached
 to.
 
 =head2 populate
@@ -96,4 +111,15 @@ Carl Franks, C<cfranks@cpan.org>
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
